@@ -5,11 +5,12 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_apigateway._jsii
 import aws_cdk.aws_cloudfront._jsii
+import aws_cdk.aws_cloudfront_origins._jsii
 import aws_cdk.aws_cloudwatch._jsii
 import aws_cdk.aws_cognito._jsii
 import aws_cdk.aws_dynamodb._jsii
@@ -31,7 +32,7 @@ import aws_cdk.aws_stepfunctions._jsii
 import aws_cdk.core._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-solutions-constructs/core", "1.55.0", __name__[0:-6], "core@1.55.0.jsii.tgz"
+    "@aws-solutions-constructs/core", "1.62.0", __name__[0:-6], "core@1.62.0.jsii.tgz"
 )
 
 __all__ = [
